@@ -2,11 +2,8 @@ package NetPacket::Ethernet;
 BEGIN {
   $NetPacket::Ethernet::AUTHORITY = 'cpan:YANICK';
 }
-{
-  $NetPacket::Ethernet::VERSION = '1.4.4';
-}
 # ABSTRACT: Assemble and disassemble ethernet packets.
-
+$NetPacket::Ethernet::VERSION = '1.5.0';
 use strict;
 use vars qw(@ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);
 
@@ -130,7 +127,13 @@ sub strip {
 #
 
 sub encode {
-    die("Not implemented");
+    my ($self) = shift; 
+
+    (my $dest = $self->{src_mac}) =~ s/://g;
+    (my $src = $self->{dest_mac}) =~ s/://g;
+
+    my $frame = pack('H12H12n a*', $dest, $src, 0x0800, $self->{data});
+    return $frame;
 }
 
 #
@@ -149,7 +152,7 @@ NetPacket::Ethernet - Assemble and disassemble ethernet packets.
 
 =head1 VERSION
 
-version 1.4.4
+version 1.5.0
 
 =head1 SYNOPSIS
 
