@@ -7,11 +7,8 @@ package NetPacket::IP;
 BEGIN {
   $NetPacket::IP::AUTHORITY = 'cpan:YANICK';
 }
-{
-  $NetPacket::IP::VERSION = '1.4.4';
-}
 # ABSTRACT: Assemble and disassemble IP (Internet Protocol) packets.
-
+$NetPacket::IP::VERSION = '1.5.0';
 use strict;
 use vars qw(@ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);
 use NetPacket;
@@ -188,21 +185,28 @@ sub encode {
     $src_ip = gethostbyname($self->{src_ip});
     $dest_ip = gethostbyname($self->{dest_ip});
 
-    # construct header to calculate the checksum
-    $hdr = pack('CCnnnCCna4a4a*', $tmp, $self->{tos},$self->{len}, 
-         $self->{id}, $offset, $self->{ttl}, $self->{proto}, 
-         $zero, $src_ip, $dest_ip, $self->{options});
+    my $fmt = 'CCnnnCCna4a4a*';
+    my @pkt = ($tmp, $self->{tos},$self->{len}, 
+               $self->{id}, $offset, $self->{ttl}, $self->{proto}, 
+               $zero, $src_ip, $dest_ip); 
+    # change format and package in case of IP options 
+    if(defined $self->{options}){ 
+        $fmt = 'CCnnnCCna4a4a*a*'; 
+        push(@pkt, $self->{options}); 
+    }
 
+    # construct header to calculate the checksum
+    $hdr = pack($fmt, @pkt);
     $self->{cksum} = NetPacket::htons(NetPacket::in_cksum($hdr));
+    $pkt[7] = $self->{cksum};
 
     # make the entire packet
-    $packet = pack('CCnnnCCna4a4a*a*', $tmp, $self->{tos},$self->{len}, 
-         $self->{id}, $offset, $self->{ttl}, $self->{proto}, 
-         $self->{cksum}, $src_ip, $dest_ip, $self->{options},
-         $self->{data});
+    if(defined $self->{data}){
+        push(@pkt, $self->{data}); 
+    } 
+    $packet = pack($fmt, @pkt);
 
     return($packet);
-
 }
 
 #
@@ -221,7 +225,7 @@ NetPacket::IP - Assemble and disassemble IP (Internet Protocol) packets.
 
 =head1 VERSION
 
-version 1.4.4
+version 1.5.0
 
 =head1 SYNOPSIS
 
